﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2016 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion
using System;
using System.Drawing;
using HeuristicLab.Common;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Problems.MultiObjectiveTestFunctions
{
    [StorableClass]
    class MOSolution : IMOFrontModel
    {
        public bool CanChangeDescription
        {
            get
            {
                return false;
            }
        }

        public bool CanChangeName
        {
            get
            {
                return false;
            }
        }

        public string Description
        {
            get
            {
                return "MYResult";
            }

            set { }
        }

        public string Filename
        {
            get { return "MyFilename"; }

            set { }
        }

        public string ItemDescription
        {
            get { return "this is MOSolutionImplementation"; }
        }

        public Image ItemImage
        {
            get
            {
                return HeuristicLab.Common.Resources.VSImageLibrary.Function;
            }
        }

        public string ItemName
        {
            get
            {
                return "MOSolution";
            }
        }

        public Version ItemVersion
        {
            get { return Version.Parse("0.1"); }
        }

        public string Name
        {
            get
            {
                return ItemName;
            }

            set { }
        }

        private double[][] qualities;

        public double[][] Qualities
        {
            get
            {
                return qualities;
            }

            set
            {
                qualities = value;
            }
        }

        private int objectives;
        public int Objectives
        {
            get
            {
                return objectives;
            }

            set
            {
                objectives = value;
            }
        }

        private double[][] solutions;
        public double[][] Solutions
        {
            get
            {
                return solutions;
            }

            set
            {
                solutions = value;
            }
        }

        private double[][] paretoFront;
        public double[][] ParetoFront
        {
            get
            {
                return paretoFront;
            }

            set
            {
                paretoFront = value;
            }
        }

        public event EventHandler DescriptionChanged;
        public event EventHandler ItemImageChanged;
        public event EventHandler NameChanged;
        public event EventHandler<CancelEventArgs<string>> NameChanging;
        public event EventHandler ToStringChanged;

        [StorableConstructor]
        protected MOSolution(bool deserializing) : base() { }


        protected MOSolution(MOSolution original, Cloner cloner) : this(original)
        {
            this.qualities = original.qualities;
            this.solutions = original.solutions;
            this.paretoFront = original.paretoFront;
            this.objectives = original.objectives;
        }
        protected MOSolution(MOSolution original) : base()
        {
            this.qualities = original.qualities;
            this.solutions = original.solutions;
            this.paretoFront = original.paretoFront;
            this.objectives = original.objectives;
        }
        protected MOSolution() : base() { }
        public MOSolution(double[][] qualities, double[][] solutions, double[][] paretoFront, int objectives)
        {
            this.qualities = qualities;
            this.solutions = solutions;
            this.paretoFront = paretoFront;
            this.objectives = objectives;
        }

        public object Clone()
        {
            return new MOSolution(this);
        }

        public IDeepCloneable Clone(Cloner cloner)
        {
            return (IDeepCloneable)Clone();
        }
    }
}
